Module: OrigenTesters::ProgramGenerators
- Extended by:
- ActiveSupport::Concern
- Includes:
- Interface
- Included in:
- BasicTestSetups, NoInterface, Test::CustomTestInterface, Test::Interface
- Defined in:
- lib/origen_testers/program_generators.rb
Overview
Include this module to create an interface that supports multiple tester types.
This module will expose generators for all test platforms supported by the Testers plugin.
Defined Under Namespace
Modules: ClassMethods
Constant Summary collapse
Instance Method Summary collapse
- #_load_generator ⇒ Object
- #initialize(options = {}) ⇒ Object
- #pre_initialize(options = {}) ⇒ Object private
- #tester ⇒ Object
Methods included from Interface
#add_description!, #add_flow_enable, #add_flow_enable=, #add_meta!, #all_pattern_references, #app_identifier, #atp, #clean_referenced_patterns, #clear_pattern_references, #clear_top_level_flow, #close, #comment, #comments, #compile, #consume_comments, #context_changed?, #context_or_parameter_changed?, #descriptions, #discard_comments, #discard_top_level_flow, #flow_generator, #generating_sub_program?, #identity_map, #import, #merge_pattern_references, #on_program_completion, #parameter_changed?, #pattern_references, #pattern_references_name, #pattern_references_name=, #platform, #record_pattern_reference, #referenced_patterns, #render, #resources_mode, resources_mode?, #resources_mode?, #set_top_level_flow, #test, #top_level_flow, #unique_test_names, #unique_test_names=, with_resources_mode, write=, write?, #write?, #write_files
Methods included from ATP::FlowAPI
#atp, #atp=, #hi_limit, #limit, #lo_limit, #loop
Instance Method Details
#_load_generator ⇒ Object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/origen_testers/program_generators.rb', line 52 def _load_generator if tester.v93k? if tester.smt8? class << self; include OrigenTesters::V93K_SMT8::Generator; end else class << self; include OrigenTesters::V93K::Generator; end end elsif tester.j750_hpt? class << self; include OrigenTesters::J750_HPT::Generator; end elsif tester.j750? class << self; include OrigenTesters::J750::Generator; end elsif tester.ultraflex? class << self; include OrigenTesters::UltraFLEX::Generator; end elsif defined? tester.class::TEST_PROGRAM_GENERATOR class << self; include tester.class::TEST_PROGRAM_GENERATOR; end else fail "The OrigenTesters::ProgramGenerators module does not support #{tester.class}!" end end |
#initialize(options = {}) ⇒ Object
45 46 |
# File 'lib/origen_testers/program_generators.rb', line 45 def initialize( = {}) end |
#pre_initialize(options = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
41 42 43 |
# File 'lib/origen_testers/program_generators.rb', line 41 def pre_initialize( = {}) _load_generator end |
#tester ⇒ Object
48 49 50 |
# File 'lib/origen_testers/program_generators.rb', line 48 def tester Origen.tester end |